@@ -5,10 +5,9 @@ the regex engine doesn't look for inner literals. Since we're doing line based
 searching, we can use them, so we need to do it ourselves.
 */
 
-use std::cmp;
-
-use regex_syntax::hir::{self, Hir, HirKind};
+use bstr::ByteSlice;
 use regex_syntax::hir::literal::{Literal, Literals};
+use regex_syntax::hir::{self, Hir, HirKind};
 
 use util;
 
@@ -37,7 +36,7 @@ impl LiteralSets {
         LiteralSets {
             prefixes: Literals::prefixes(expr),
             suffixes: Literals::suffixes(expr),
-            required: required,
+            required,
         }
     }
 
@@ -101,7 +100,12 @@ impl LiteralSets {
         // helps with case insensitive matching, which can generate lots of
         // inner required literals.
         let any_empty = req_lits.iter().any(|lit| lit.is_empty());
-        if req.len() > lit.len() && req_lits.len() > 1 && !any_empty {
+        let any_white = has_only_whitespace(&req_lits);
+        if req.len() > lit.len()
+            && req_lits.len() > 1
+            && !any_empty
+            && !any_white
+        {
             debug!("required literals found: {:?}", req_lits);
             let alts: Vec<String> = req_lits
                 .into_iter()
@@ -110,9 +114,74 @@ impl LiteralSets {
             // We're matching raw bytes, so disable Unicode mode.
             Some(format!("(?-u:{})", alts.join("|")))
         } else if lit.is_empty() {
-            None
+            // If we're here, then we have no LCP. No LCS. And no detected
+            // inner required literals. In theory this shouldn't happen, but
+            // the inner literal detector isn't as nice as we hope and doens't
+            // actually support returning a set of alternating required
+            // literals. (Instead, it only returns a set where EVERY literal
+            // in it is required. It cannot currently express "either P or Q
+            // is required.")
+            //
+            // In this case, it is possible that we still have meaningful
+            // prefixes or suffixes to use. So we look for the set of literals
+            // with the highest minimum length and use that to build our "fast"
+            // regex.
+            //
+            // This manifests in fairly common scenarios. e.g.,
+            //
+            //     rg -w 'foo|bar|baz|quux'
+            //
+            // Normally, without the `-w`, the regex engine itself would
+            // detect the prefix correctly. Unfortunately, the `-w` option
+            // turns the regex into something like this:
+            //
+            //     rg '(^|\W)(foo|bar|baz|quux)($|\W)'
+            //
+            // Which will defeat all prefix and suffix literal optimizations.
+            // (Not in theory---it could be better. But the current
+            // implementation isn't good enough.) ... So we make up for it
+            // here.
+            if !word {
+                return None;
+            }
+            let p_min_len = self.prefixes.min_len();
+            let s_min_len = self.suffixes.min_len();
+            let lits = match (p_min_len, s_min_len) {
+                (None, None) => return None,
+                (Some(_), None) => {
+                    debug!("prefix literals found");
+                    self.prefixes.literals()
+                }
+                (None, Some(_)) => {
+                    debug!("suffix literals found");
+                    self.suffixes.literals()
+                }
+                (Some(p), Some(s)) => {
+                    if p >= s {
+                        debug!("prefix literals found");
+                        self.prefixes.literals()
+                    } else {
+                        debug!("suffix literals found");
+                        self.suffixes.literals()
+                    }
+                }
+            };
+
+            debug!("prefix/suffix literals found: {:?}", lits);
+            if has_only_whitespace(lits) {
+                debug!("dropping literals because one was whitespace");
+                return None;
+            }
+            let alts: Vec<String> =
+                lits.into_iter().map(|x| util::bytes_to_regex(x)).collect();
+            // We're matching raw bytes, so disable Unicode mode.
+            Some(format!("(?-u:{})", alts.join("|")))
         } else {
             debug!("required literal found: {:?}", util::show_bytes(lit));
+            if lit.chars().all(|c| c.is_whitespace()) {
+                debug!("dropping literal because one was whitespace");
+                return None;
+            }
             Some(format!("(?-u:{})", util::bytes_to_regex(&lit)))
         }
     }
@@ -140,25 +209,28 @@ fn union_required(expr: &Hir, lits: &mut Literals) {
         HirKind::Group(hir::Group { ref hir, .. }) => {
             union_required(&**hir, lits);
         }
-        HirKind::Repetition(ref x) => {
-            match x.kind {
-                hir::RepetitionKind::ZeroOrOne => lits.cut(),
-                hir::RepetitionKind::ZeroOrMore => lits.cut(),
-                hir::RepetitionKind::OneOrMore => {
-                    union_required(&x.hir, lits);
-                    lits.cut();
-                }
-                hir::RepetitionKind::Range(ref rng) => {
-                    let (min, max) = match *rng {
-                        hir::RepetitionRange::Exactly(m) => (m, Some(m)),
-                        hir::RepetitionRange::AtLeast(m) => (m, None),
-                        hir::RepetitionRange::Bounded(m, n) => (m, Some(n)),
-                    };
-                    repeat_range_literals(
-                        &x.hir, min, max, x.greedy, lits, union_required);
-                }
+        HirKind::Repetition(ref x) => match x.kind {
+            hir::RepetitionKind::ZeroOrOne => lits.cut(),
+            hir::RepetitionKind::ZeroOrMore => lits.cut(),
+            hir::RepetitionKind::OneOrMore => {
+                union_required(&x.hir, lits);
             }
-        }
+            hir::RepetitionKind::Range(ref rng) => {
+                let (min, max) = match *rng {
+                    hir::RepetitionRange::Exactly(m) => (m, Some(m)),
+                    hir::RepetitionRange::AtLeast(m) => (m, None),
+                    hir::RepetitionRange::Bounded(m, n) => (m, Some(n)),
+                };
+                repeat_range_literals(
+                    &x.hir,
+                    min,
+                    max,
+                    x.greedy,
+                    lits,
+                    union_required,
+                );
+            }
+        },
         HirKind::Concat(ref es) if es.is_empty() => {}
         HirKind::Concat(ref es) if es.len() == 1 => {
             union_required(&es[0], lits)
@@ -193,7 +265,7 @@ fn union_required(expr: &Hir, lits: &mut Literals) {
 fn repeat_range_literals<F: FnMut(&Hir, &mut Literals)>(
     e: &Hir,
     min: u32,
-    max: Option<u32>,
+    _max: Option<u32>,
     _greedy: bool,
     lits: &mut Literals,
     mut f: F,
@@ -204,19 +276,13 @@ fn repeat_range_literals<F: FnMut(&Hir, &mut Literals)>(
         // just treat it as `e*`.
         lits.cut();
     } else {
-        let n = cmp::min(lits.limit_size(), min as usize);
         // We only extract literals from a single repetition, even though
         // we could do more. e.g., `a{3}` will have `a` extracted instead of
         // `aaa`. The reason is that inner literal extraction can't be unioned
         // across repetitions. e.g., extracting `foofoofoo` from `(\w+foo){3}`
         // is wrong.
         f(e, lits);
-        if n < min as usize {
-            lits.cut();
-        }
-        if max.map_or(true, |max| min < max) {
-            lits.cut();
-        }
+        lits.cut();
     }
 }
 
@@ -260,12 +326,12 @@ fn is_simple(expr: &Hir) -> bool {
         HirKind::Empty
         | HirKind::Literal(_)
         | HirKind::Class(_)
-        | HirKind::Repetition(_)
         | HirKind::Concat(_)
         | HirKind::Alternation(_) => true,
         HirKind::Anchor(_)
         | HirKind::WordBoundary(_)
-        | HirKind::Group(_) => false,
+        | HirKind::Group(_)
+        | HirKind::Repetition(_) => false,
     }
 }
 
@@ -279,10 +345,21 @@ fn count_byte_class(cls: &hir::ClassBytes) -> u32 {
     cls.iter().map(|r| 1 + (r.end() as u32 - r.start() as u32)).sum()
 }
 
+/// Returns true if and only if any of the literals in the given set is
+/// entirely whitespace.
+fn has_only_whitespace(lits: &[Literal]) -> bool {
+    for lit in lits {
+        if lit.chars().all(|c| c.is_whitespace()) {
+            return true;
+        }
+    }
+    false
+}
+
 #[cfg(test)]
 mod tests {
-    use regex_syntax::Parser;
     use super::LiteralSets;
+    use regex_syntax::Parser;
 
     fn sets(pattern: &str) -> LiteralSets {
         let hir = Parser::new().parse(pattern).unwrap();
@@ -328,4 +405,24 @@ mod tests {
         // assert_eq!(one_regex(r"a.*c"), pat("a"));
         assert_eq!(one_regex(r"a(.*c)"), pat("a"));
     }
+
+    #[test]
+    fn regression_1319() {
+        // Regression from:
+        // https://github.com/BurntSushi/ripgrep/issues/1319
+        assert_eq!(
+            one_regex(r"TTGAGTCCAGGAG[ATCG]{2}C"),
+            pat("TTGAGTCCAGGAG"),
+        );
+    }
+
+    #[test]
+    fn regression_1537() {
+        // Regression from:
+        // https://github.com/BurntSushi/ripgrep/issues/1537
+        assert_eq!(one_regex(r";(.*,)"), pat(";"));
+        assert_eq!(one_regex(r";((.*,))"), pat(";"));
+        assert_eq!(one_regex(r";(.*,)+"), pat(";"),);
+        assert_eq!(one_regex(r";(.*,){1}"), pat(";"),);
+    }
 }
